# ParameterTransformer subpackage developing notes

These notes are used for keeping track of ToDos and porting information.

## Porting status
- Rotating and rescaling has been implemented.

## Matlab references
-  Everything in: [warpvars_vbmc.m](https://github.com/acerbilab/vbmc/blob/master/shared/warpvars_vbmc.m)
